@@ -1,4 +1,4 @@
-"""A Suite of common debug routines."""
+"""A suite of common debug routines."""
 
 from .sparse_memory import SparseMemory
 from .debug_manager import DebugManager
